---
name: Bug report
about: Report a bug with Singularity Registry Client

---

**Describe the bug**

**To Reproduce**
Steps to reproduce the behavior:

**Expected behavior**
A clear and concise description of what you expected to happen.

**Version of Singularity and Singularity Registry Client**

Anything else?
